function w = faddeeva(z,N)
% w = faddeeva(z,N) 
%evaluates Faddeeva function
% w = exp(-z^2)*(1 + 2*i/sqrt(pi)*int_^z exp(t^2) dt)
%N is an optional argument specifying the approximation level
%
%Uses code based on Weideman's algorithm by Kuan Xu, see
%http://www2.maths.ox.ac.uk/chebfun/examples/ode/html/DawsonIntegral.html
%retrieved December 2014

if nargin==1
    N=36;
end
M = 2*N;  M2 = 2*M;  k = (-M+1:1:M-1)';      % M2 = no. of sampling points.
L = sqrt(N/sqrt(2));                         % Optimal choice of L.
theta = k*pi/M; t = L*tan(theta/2);          % Define variables theta and t.
f = exp(-t.^2).*(L^2+t.^2); f = [0; f];      % Function to be transformed.
a = real(fft(fftshift(f)))/M2;               % Coefficients of transform.
a = flipud(a(2:N+1));                        % Reorder coefficients.
Z = (L+1i*z)./(L-1i*z); p = polyval(a,Z);    % Polynomial evaluation.
w = 2*p./(L-1i*z).^2+(1/sqrt(pi))./(L-1i*z); % Evaluate w(z).
end
