function parameters = parameter_generator(direction)
%parameters = paramter_generation(direction)
%Outputs complete structure for running steady_solver.m or
%asymptotic_solution.m; individual fields can be altered to solve different
%physical solutions or improve solver performance
%Input argument:
%   direction:  specify direction of flow as +1 (flow is up) or -1 (flow is
%   down)
%Output argument:
%   parameters: complete parameter structure for running steady_solver.m.
%   See code and documentation for steady_solver.m / asymptotic_solution.m
%   or their subroutines for details
%
%Christian Schoof, January 2015

if nargin == 0
    direction = -1;
elseif abs(direction) ~= 1
    if direction == 0, error('direction cannot be zero'), end
    direction = direction/abs(direction);
end

parameters.display = true;
parameters.srchparams.verbose = 2;
parameters.srchparams.tolnorm = 1e-7;
parameters.srchparams.itmax = 10;

parameters.weights.N_0 = 1;
parameters.weights.phi_0 = 1;
parameters.weights.q_0 = 1;

parameters.model.a = 1;
parameters.model.Pe = 1;
parameters.model.Pe_phi = 1;
parameters.model.g = -1;
parameters.model.delta = .125;
parameters.model.alpha = 2.33;
parameters.model.u_0 = direction;
parameters.model.u_z = 0;
parameters.model.T_0 = -.1;
parameters.model.N_0 = 2;
parameters.model.phi_0 = .2;
parameters.model.z_c = 1;
parameters.model.z_t = 100*sqrt(eps);
parameters.model.z_ct = 0.5;
parameters.model.phi_tfm_farfield = 20;
parameters.model.zero_velocity_tolerance = 10;
parameters.model.zero_characteristic_tolerance = 20;

parameters = grid_generator(parameters);

end